# LRGbinding module - for saucerman B1AR as GPCR

#     return (k_kinetic, N_cT, K_C, W) kinetic parameters, constraints, and vector of volumes in each
# compartment (pL) (1 if gating variable, or in element corresponding to
# kappa)

import numpy as np 

def kinetic_parameters(M, include_type2_reactions, dims, V):
    # Set the kinetic rate constants.
    # original model had reactions that omitted enzymes as substrates e.g. BARK
    # convert unit from 1/s to 1/uM.s by dividing by conc of enzyme
    # all reactions were irreversible, made reversible by letting kr ~= 0
    
    num_cols = dims['num_cols']
    num_rows = dims['num_rows']

    # concentration of BARK = 0.6uM (crude approx from litsearch, for GRK)
    bigNum = 1e6
    fastKineticConstant = bigNum
    
    KRc = 33    # uM  Kc
    KRL = 0.285 # uM  Kl
    KRr = 0.062 # uM  Kr
    kRcp = fastKineticConstant
    kRcm = kRcp*KRc
    # ksig2p = fastKineticConstant
    # ksig2m = ksig2p*Ksig2
    kRrp = fastKineticConstant
    kRrm = kRrp*KRr
    kRLp = fastKineticConstant
    # find kRLm using detailed balance if a closed loop exists
    # kRLm = kRcm*ksig2m*kRrp*kRLp/(kRcp*ksig2p*kRrm)
    kRLm = kRLp*KRL
        
    k_kinetic = [
        kRcp, kRrp, kRLp,
        kRcm, kRrm, kRLm
        ]

    # CONSTRAINTS
    N_cT = []
    K_C = []

    # volume vector
    W = list(np.append([1] * num_cols, [V['V_myo']] * num_rows))

    return (k_kinetic, [N_cT], K_C, W) 